Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

543 documents were found matching the selected criteria.
Page: [ 1] 2 3 4 5 6 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
Saffold v. Croom | 100806 | Arbitration agreement; arbitrability; de novo; federal arbitration act; Trial court erred in denying defendant’s motion to compel arbitration where parties had an arbitration agreement that covered the alleged dispute as well as an arbitrability provision that required the court to refer questions regarding the scope of the arbitration clause’s coverage to the arbitrator. | Gallagher | 7/24/2014 | 2014-Ohio-3241
State v. L.S. | 100793 | Jurisdiction; juvenile; State conceded that the court of common pleas lacked jurisdiction to convict minor defendant. | Gallagher | 7/24/2014 | 2014-Ohio-3240
State v. Totty | 100788 | Anders brief; Crim.R. 11; Allied offenses; postrelease control; forfeiture; Following filing of an Anders brief by appellant’s counsel, the court conducted an independent review of the entire record as well as a review of potential errors raised by counsel and found no errors in appellant’s plea or sentencing. | Gallagher | 7/24/2014 | 2014-Ohio-3239
State v. Wells | 100732 | Anders brief; withdraw appeal; guilty plea Crim R. 11; judgment affirmed. Defendant’s guilty plea was knowingly, intelligently, and voluntarily made. Thus, the appeal to is frivolous under Anders, and appellate counsel’s request to withdraw and affirm the trial court’s judgment is granted. | Kilbane | 7/24/2014 | 2014-Ohio-3238
Simic v. Accountancy Bd. of Ohio | 100618 | CPA certificate; firm registration renewal; R.C. 4701.16; administrative appeal; R.C. 119.12; Ohio Adm.Code 4701-13-01; abuse of discretion. The trial court abused its discretion in relying on evidence that appellant violated a cease and desist order when the administrative agency’s hearing was limited to the appellant’s failure to submit a triennial registration fee. The administrative agency’s adjudication order is void because the agency failed to provide notice of the violation for which the appellant was sanctioned. | Gallagher | 7/24/2014 | 2014-Ohio-3237
Klik v. Moyer | 100576 | Final order; Civ.R. 60(B); relief from judgment; QDRO; timeliness. The trial court did not abuse its discretion in denying the plaintiff relief from a 1993 divorce decree, after plaintiff waited 18 years before taking any action to seek a QDRO effectuating plaintiff’s award of an interest in her husband’s pension. | Gallagher | 7/24/2014 | 2014-Ohio-3236
Alden v. FirstEnergy Corp. | 100575 | Nunc pro tunc; dismissal; jurisdiction. Trial court lacked jurisdiction to issue a nunc pro tunc order that changed its dismissal with prejudice to one without prejudice. Such a change is substantive and not clerical. | Blackmon | 7/24/2014 | 2014-Ohio-3235
Third Fed. S. & L. Assn. of Cleveland v. Formanik | 100562, 100810 | Civ.R. 60(B); motion to vacate judgment; objections; magistrate’s decision; statute of frauds; modification; course of performance; pro se; excusable neglect; inaction; operative facts; counsel; withdraw; abuse of discretion; motion to quash; subpoena. Trial court abused its discretion in denying a Civ.R. 60(B) motion for relief from the trial court’s judgment adopting a magistrate’s decision and ruling against appellants on their counterclaims where appellants’ trial counsel had recently withdrawn from the case and appellants substantiated their efforts to retain new counsel and had prepared pro se objections to the magistrate’s decision that were not properly filed. Appellants presented operative facts warranting relief, and the grounds for relief from judgment were met. Appellee’s defense of the statute of frauds was rejected where it was not raised at trial and did not preclude a claim of modification through course of performance. The trial court did not abuse its discretion in allowing trial counsel to withdraw and in granting a motion to quash a subpoena. | Gallagher | 7/24/2014 | 2014-Ohio-3234
Ryerson v. White | 100547 | Objections to magistrate’s decision, asset transfer; fiduciary; confidential relationship; presumption of undue influence; abuse of discretion; manifest weight; fraudulent conduct; handwriting expert; admission of evidence; Evid.R. 608(B); harmless error. | Gallagher | 7/24/2014 | 2014-Ohio-3233
State v. Donat | 100485 | Consecutive sentence; finding; mitigating factors; mental health condition; ineffective assistance of counsel; medication; plea hearing. Record supported the findings trial court must make before imposing a consecutive sentence. Defense counsel’s decision not to request continuance did not constitute ineffective assistance of counsel where defendant had stopped taking pain medication several days before the plea hearing, and defendant was not under the influence of medication at the time of the plea. | Gallagher | 7/24/2014 | 2014-Ohio-3232
State v. Paster | 100458 | Consecutive sentence; findings; R.C. 2929.14(C); sufficient evidence; importuning; attempted unlawful sexual conduct with minor; authentication. Defendant’s convictions affirmed, sentenced reversed, and remanded for resentencing. The trial court did not comply with R.C. 2929.14(C)when it did not make the required findings. The state presented sufficient evidence to sustain defendant’s importuning and attempted unlawful sexual conduct with a minor convictions. Defendant sent texts to a “15-year-old girl” stating what he wanted to do with her sexually and defendant met girl at place they arranged to meet. Witnesses direct testimony of own cell phone records and internet print out was sufficient evidence to authenticate these documents. | Kilbane | 7/24/2014 | 2014-Ohio-3231
State v. Wright | 100433 | Sentence was not erroneous where trial court stated that it considered the statutory sentencing factors in R.C. 2929.11 and 2929.12 and journal entry states that court considered all required factors of the law; court is not obligated to give any particular weight or consideration to any sentencing factor. | Kilbane | 7/24/2014 | 2014-Ohio-3230
State v. Evans | 100382 | Consecutive sentences findings, not disproportionate, competency, stipulation to competency. The trial court did not make the necessary finding that consecutive sentences are not disproportionate to the seriousness of the offender’s conduct. The trial court’s judgment sentencing of consecutive terms is reversed with the limited remand for the purpose of determining whether consecutive sentences should be imposed. Further action by the trial court was not required when the appellant stipulated to the competency report, and therefore failed to maintain the competency issue. The judgment of the trial court is affirmed. | Gallagher | 7/24/2014 | 2014-Ohio-3229
State v. Glover | 100330, 100331 | Postconviction relief; federal constitutional right to effective counsel in postconviction proceedings; ineffective assistance of counsel; codefendants; jurisdiction. Trial court did not err in denying codefendants successive petition for postconviction relief, pursuant to R.C. 2953.23(A)(1). Martinez v. Ryan, 566 U.S. 1, 132 S.Ct. 1309, 182 L.Ed.2d 272 (2012) does not apply to the instant case, where codefendants were afforded the opportunity to and did in fact raise the issue of ineffective assistance of counsel in prior appeals. | Gallagher | 7/24/2014 | 2014-Ohio-3228
State v. Klembus | 100068 | OVI; repeat OVI offender specification; prior felony offenses; R.C. 2941.1413(A); violation of equal protection and due process of law; proof of additional element. R.C. 2941.1413 allows the prosecutor to arbitrarily obtain a greater prison sentence for the underlying offense without proof of any additional element, fact or circumstance. The repeat OVI offender specification violates equal protection because it gives the state unfettered discretion to choose between two significantly different punishments when charging similarly situated OVI offenders. | Gallagher | 7/24/2014 | 2014-Ohio-3227
Wells Fargo Bank, NA v. Froimson | 99720 | foreclosure; standing; holder; summary judgment; evidentiary quality materials. In a foreclosure action, the trial court’s order granting summary judgment was affirmed. The plaintiff bank had standing to bring the action as it was the successor of the original lender and was the holder of the note at the time that the complaint was filed. The summary judgment motion was supported by evidentiary quality materials that established that the bank was entitled to a judgment as a matter of law. | Rocco | 7/24/2014 | 2014-Ohio-3225
State v. Smith | 98547 | Consecutive sentence; remand; jurisdiction; resentencing. Consecutive sentence imposed on remand affirmed. Court was not required to make findings for imposition of consecutive sentence because court was instructed by this court to simply reinstate defendant’s original conviction minus one year for a firearm specification of which defendant was acquitted. | Gallagher | 7/24/2014 | 2014-Ohio-3224
Pointer v. Russo | 101548 | Writ; habeas corpus; fatally defective; commitment papers; R.C. 2725.04(A). Petition for writ of habeas corpus is dismissed because it is fatally defective for failure to comply with R.C. 2725.04(D) and is without merit since relator’s sentence has not yet expired. | Celebrezze | 7/23/2014 | 2014-Ohio-3244
State ex rel. Green v. Saffold | 101151 | Procedendo, procedural deficiencies, moot. Relator failed to comply with the requirements for filing an action seeking a writ of procedendo and the action is moot because the respondent judge issued a ruling on relator’s motion for jail time credit. | Rocco | 7/22/2014 | 2014-Ohio-3242
State v. Ellis | 99830 | Ineffective assistance of appellate counsel; App.R. 26(B); aggravated murder, involuntary manslaughter; lesser included offense; expert qualifications; and double jeopardy. The double jeopardy clause does not prohibit multiple charges arising from the same incident. The trial court’s merger of multiple offenses precluded a double jeopardy argument on multiple punishments. Involuntary manslaughter is a lesser included offense of aggravated murder. An indictment for aggravated murder puts a defendant on notice that he must be ready to defend on involuntary manslaughter. The forensics detective was qualified to be an expert, and counsel need not raise the argument that there should have been a pretrial hearing to determine his qualifications. | Blackmon | 7/22/2014 | 2014-Ohio-3226
State v. Moore | 57223 | App.R. 26(B), untimely; no good cause. Untimely application to reopen pursuant to App.R. 26(B) is denied where applicant fails to establish good cause for the delayed filing. | Kilbane | 7/18/2014 | 2014-Ohio-3223
State v. Pettis | 100851 | Petition for postconviction relief; ineffective assistance of counsel; rape; res judicata. The trial did not abuse its discretion when it denied appellant’s petition for postconviction relief. The trial court did not commit error when it denied appellant’s claim of ineffective assistance of counsel. The judgment of the trial court is affirmed. | Gallagher | 7/17/2014 | 2014-Ohio-3147
Metro Diplomat Healthcare | 100799 | Civ.R. 10(D)(2); affidavit of merit; medical claim. Court erred by finding that claims that did not raise issues of medical negligence were subject to the affidavit of merit requirement of Civ.R. 10(D). Court did not err by finding that a nurse practitioner was unqualified to render an opinion in an affidavit of merit on whether a psychiatrist breached the applicable duty of care. | Stewart | 7/17/2014 | 2014-Ohio-3146
Srokowski v. Shay | 100739 | Civ.R. 12(B)(6). Trial court did not err in denying city’s motion to dismiss as to Srokowski’s claims for negligent infliction of emotional distress and negligence because, in this early stage of the proceedings, accepting as true all material allegations of the complaint and making all reasonable inferences in favor of Srokowski, it is not clear beyond dispute that this matter involves a governmental function. | Kilbane | 7/17/2014 | 2014-Ohio-3145
Strongsville v. J.M.B. | 100680 | R.C. 2953.32(B); R.C. 2953.61; Application for Expungement; Hearing; Multiple Offenses; Differing Depositions. Trial court erred in summarily denying application for expungement without holding a hearing as required by R.C. 2953.32(B); R.C. 2953.61, which applies to expungement applications involving multiple offenses that arise as a result of or in connection with the same act and the offenses have differing dispositions, did not apply to the defendant’s application because the defendant was convicted of both offenses. | Keough | 7/17/2014 | 2014-Ohio-3144
State v. Dines | 100647 | R.C. 2929.191/correction to judgment of conviction; completion of sentence. The trial court did not err in not considering R.C. 2929.191(A)(1) and (A)(2) in its procedure for sentencing appellant. This portion of the revised code applies to sentences imposed before July 11, 2006. Appellant was sentenced on January 7, 2007. Remand for a nunc pro tunc entry to correct the omission of notification of postrelease control where appellant failed to show a deficiency of notification at sentencing hearing is proper. Appellant had served his prison term for one offense of his total sentence. It was error for the trial court to add postrelease control for that portion of appellant’s sentence. | Jones | 7/17/2014 | 2014-Ohio-3143
State v. Shabazz | 100623 | Motion for a new trial; Crim. R. 33; res judicata - Res judicata bars defendant’s successive motion for a new trial where arguments raised in the motion were previously raised and rejected in prior appeals. Notwithstanding, defendant failed to satisfy his burden of proving he was unavoidably prevented from discovering the purported new evidence. | Keough | 7/17/2014 | 2014-Ohio-3142
State v. Dent | 100605 | Crim.R. 32.1; postsentence motion to withdraw plea; abuse of discretion; res judicata. The trial court did not abuse its discretion in denying a postsentence motion to withdraw a guilty plea advancing claims that could have been raised in the direct appeal of the underlying conviction. | Gallagher | 7/17/2014 | 2014-Ohio-3141
State v. Blackley | 100574 | Sentence, maximum, more than co-defendant for lesser offense. Because the trial court explained the basis for its decision to impose a maximum prison term on appellant for committing gross sexual imposition, while imposing the same prison sentence on the co-defendant who pleaded guilty to rape, appellant’s sentence was not contrary to law. | Rocco | 7/17/2014 | 2014-Ohio-3140
State v. Gray | 100492 | Trial court’s determination that defendant-appellant was a sexual predator was not against the manifest weight of the evidence. | Rocco | 7/17/2014 | 2014-Ohio-3139
State v. Williams | 100488 | Consecutive sentences; R.C. 2929.14(C)(4); R.C. 2953.08(G)(2); standard of review; clearly erroneous; abuse of discretion. Court made all of the required findings necessary to impose consecutive sentences under R.C. 2929.14(C)(4) and the record on appeal did not show those findings to be so clearly erroneous as to warrant reversal. | Stewart | 7/17/2014 | 2014-Ohio-3138
State v. Matthews | 100476 | R.C. 2929.14/resentencing hearing/jurisdiction; consecutive sentences. Appellant failed to seek reconsideration of this court’s judgment pursuant to App.R. 26(A) in her direct appeal, therefore, her current assignment of error regarding modification of sentence pursuant to R.C. 2953.08 is not properly before this court. The trial court erred where it did not make the requisite statutory findings for consecutive sentences. | Jones | 7/17/2014 | 2014-Ohio-3137
State v. Bidinost | 100466 | Sexual predator classification; hearing; likely to reoffend; clear and convincing evidence; judgment reversed. The state failed to prove by clear and convincing evidence that defendant is a sexual predator. The trial court did not state that defendant was likely to commit future offenses. | Kilbane | 7/17/2014 | 2014-Ohio-3136
Solon v. Hrivnak | 100411 | OVI; field sobriety tests; manifest weight; sufficiency of evidence. Although appellant offered alternative explanations for his poor performance in the field sobriety tests, his conviction of OVI was neither supported by insufficient evidence nor against the manifest weight of the evidence. | McCormack | 7/17/2014 | 2014-Ohio-3135
State v. Taylor | 100315 | Inconsistent Verdicts; Evid. R. 611; Child Witness; Consecutive Sentences; Sexually Violent Predator Specification; Court Costs. Consistency between verdicts on several counts of an indictment is unnecessary where the defendant is convicted on one or some counts, and acquitted on others; Court did not err by allowing victim impact representative sit near the testifying child who was crying uncontrollably; Court complied with R.C. 2929.14(C) in imposing consecutive sentences; R.C. 2971.01(H)(1) allows for the inclusion of a sexually violent predator specification in the indictment of one being charged for the first time with a sexually violent offense; Court erred by imposing cost of prosecution as court costs when no evidence of the amount was presented. | Blackmon | 7/17/2014 | 2014-Ohio-3134
State v. Brothers | 100163, 100164 | Sufficiency; Crim.R. 29/motion for acquittal; manifest weight; right to confront witnesses. Evidence submitted at trial was sufficient to support appellant’s conviction. Appellant, granted an expert at state’s expense, failed to test all samples retrieved at the scene, and appellant’s trial counsel did not refute the one sample that was tested. The sample tested along with DNA found on the victim was compelling enough to support appellant’s conviction. The trial court’s admittance of testimony by BCI forensic examiners was not error. The examiners testified to the results of the sample taken and tested and to statistical DNA evidence derived from the FBI database. This statistical DNA evidence has previously been determined to not be testimonial. | Jones | 7/17/2014 | 2014-Ohio-3132
Cleveland v. Farrell | 100136 | Crim.R. 12( C)(2) motion to dismiss; Cleveland Codified Ordinance 433.03/speed; sufficiency; manifest weight. The traffic ticket indicated the basic facts and set forth the ordinance at issue thereby giving appellant notice of the nature of the charge. The trial court did not err in denying appellant’s motion to dismiss the charges. Operating a vehicle in excess of the limitations sets forth a prima facie violation, and appellant provided no evidence to overcome the state’s case. There was no error in the court’s finding of guilt. | Jones | 7/17/2014 | 2014-Ohio-3131
Benson v. Callahan | 101435 | Mandamus and/or procedendo; moot, Loc.App.R. 45(B)(1)(a) sworn affidavit; R.C. 2969.25(A) sworn affidavit. Relator’s complaint for writ of mandamus and/or procedendo is moot. Respondent denied the motion to vacate and set aside sentence. In addition, the complaint is subject to dismissal for failure to comply with Loc.App.R. 45(B)(1)(a) and R.C. 2969.25(A). | Kilbane | 7/13/2014 | 2014-Ohio-3243
State v. Scahel | 100705 | Speedy trial, statutory, constitutional. Court erred by deciding motion to dismiss for want of speedy trial on constitutional grounds because the motion to dismiss raised only statutory grounds as a basis for dismissal. | Stewart | 7/10/2014 | 2014-Ohio-3042
State v. Smith | 100792 | Bootstrapping; Untimely appeal. This court lacks jurisdiction to consider appellant’s appeal. Appellant’s previous appeal was dismissed as untimely, and his act in subsequently refiling an identical motion in the trial court for that court to deny again constituted “bootstrapping” and did not thereby “restart” the clock for purposes of App.R. 4(A). | Rocco | 7/10/2014 | 2014-Ohio-3041
State v. Mace | 100779 | Motion to vacate; postrelease control. The trial court did not err in denying appellant’s motion to vacate postrelease control, however, because appellant has completed his sentence, this case is remanded for an entry stating that appellant is not subject to postrelease control. | Jones | 7/10/2014 | 2014-Ohio-3040
S. Euclid v. Korn | 100747 | Sufficient evidence; manifest weight; South Euclid Municipal Code Section 331.16; right of way at intersections. - The city presented insufficient evidence to prove each element of the offense beyond a reasonable doubt; defendant cannot be punished for the city’s failure to cite him under the proper ordinance. | Celebrezze | 7/10/2014 | 2014-Ohio-3039
State v. Simmons | 100638 | Untimely postconviction relief petition; R.C. 2953.21. - Trial court did not err when it denied defendant’s untimely petition for postconviction relief. | Boyle | 7/10/2014 | 2014-Ohio-3038
State v. Pyne | 100580 | Postrelease control; R.C. 2967.28; escape; R.C. 2921.34(A)(3); notification. - When a trial court properly notifies a defendant at sentencing about postrelease control and the consequences of violating postrelease control, but fails to incorporate that notice into the sentencing entry, the postrelease control is void and the defendant cannot later be charged with escape for violating postrelease control. | Boyle | 7/10/2014 | 2014-Ohio-3037
State v. Stowes | 100540 | R.C. 2929.14( C)(4)/consecutive sentences. The trial court made the requisite statutory findings for consecutive sentences and therefore did not err where it imposed consecutive sentences. | Jones | 7/10/2014 | 2014-Ohio-3036
In re A.S. | 100530, 100531 | Legal custody; best interest of the child; R.C. 2151.353; preponderance of the evidence; abuse of discretion. — The trial court did not abuse its discretion in awarding legal custody to Grandmother as its decision was supported by a preponderance of the evidence and was in the best interest of the children. | McCormack | 7/10/2014 | 2014-Ohio-3035
State v. Smith | 100501 | Preindictment delay; prejudice; rape; gross sexual imposition; manifest weight. - Defendant failed to establish that the preindictment delay caused him actual prejudice; defendant’s rape and gross sexual imposition convictions were not against the manifest weight of the evidence. | Celebrezze | 7/10/2014 | 2014-Ohio-3034
Euclid Hous. Partners, Ltd. v. Wells Fargo Bank, N.A. | 100421 | Non-recourse loan; default; contract interpretation; mortgage; note; guaranty; summary judgment; damages. Trial court erred in determining that appellant-guarantor was personally liable under the single-purpose entity provision set forth in the note and the guaranty. The unambiguous language set forth that only the borrower was liable if that provision was violated. Because the money damages awarded to appellee-lender were based on the trial court’s erroneous conclusion, the case was remanded to determine the proper extent of the guarantor’s liability. | Rocco | 7/10/2014 | 2014-Ohio-3033
State v. Wells | 100365 | Rape; consecutive sentences; proportionality; consistency; sentencing factors; uncharged crimes; inaccuracy in a PSI; R.C. 2907.02; R.C. 2953.08; R.C. 2929.11; R.C. 2929.12; R.C. 2929.14(C)(4); R.C. 2951.03. - Appellant’s sentence of 12 years for rape and a community control violation was not an abuse of discretion because that is not the standard of review. The sentence imposed did not take into consideration improper factors or uncharged allegations, but the court failed to make all the findings necessary to impose consecutive sentences, requiring a limited remand. | Celebrezze | 7/10/2014 | 2014-Ohio-3032
Westlake v. Gordon | 100295 | Motion to suppress; furtive movements; search of vehicle; probable cause. Trial court erred in granting motion to suppress evidence found during search of vehicle after passenger voluntarily relinquished criminal tools during a consensual encounter with the responding police officer. | Gallagher | 7/10/2014 | 2014-Ohio-3031
State v. Liuzzo | 99545 | App.R. 26(B); granted in part, denied in part; R.C. 2947.23( C); allied offenses; R.C. 2929.11; computer restriction. Application to reopen fails to establish ineffective assistance of counsel concerning allied offenses and sentencing issues that were raised in the initial appeal and where an error concerning notification regarding the performance of community service for unpaid court costs is harmless. Application to reopen is granted regarding a computer restriction that was imposed as part of the prison sentence and but is not authorized by statute. Application granted in part and denied in part. | Jones | 7/9/2014 | 2014-Ohio-3030
In re T.H. | 100852 | Permanent custody; “12 of 22”; best interests of the child. Trial court’s decision granting permanent custody of minor child to CCDCFS was supported by competent credible evidence where the evidence showed that the minor child has been in the temporary custody of a public services agency for 12 or more months of a consecutive 22 month period and that permanent custody was in the child’s best interests. | Keough | 7/3/2014 | 2014-Ohio-2985
State v. Richardson | 100838 | Anders brief; frivolous appeal; independent review. After an independent review pursuant to Anders v. California, 386 U.S. 738, 87 S.Ct. 1396, 18 L.Ed.2d 493, this court found no errors in the trial court that were prejudicial to appellant. Appointed counsel’s motion to withdraw is granted. | Boyle | 7/3/2014 | 2014-Ohio-2984
Smith v. ExpressJet Airlines, Inc. | 100832 | Appeal dismissed; privileged documents. The appeal has been rendered moot because the trial court granted summary judgment on grounds unrelated to the disputed materials while the appeal was pending. | Blackmon | 7/3/2014 | 2014-Ohio-2983
Deutsche Bank Natl. Co. v. Caldwell | 100594 | Standing; final, appealable order; interior view; appraisal; foreclosure; sheriff’s sale; R.C. 2329.17; confirmation of sale; actual view. An appeal from a confirmation of sale includes only issues that arise from that proceeding. The failure to appeal from the order of sale precludes the argument of issues that arise from that portion of the proceeding. Where no prejudice results when an appraisal is conducted without an interior view of the premises subject to foreclosure, the trial court does not err in confirming the order of sale. | Celebrezze | 7/3/2014 | 2014-Ohio-2982
State v. Ervin | 100528 | Delay in resentencing; R.C. 2929.14(C)(4)/consecutive sentences; allied offenses; imposition of costs. Where appellant was serving a 101-year sentence beyond his current 31-year sentence and could not have been released during the delayed period for resentencing him, appellant suffered no prejudice because of the delay. The trial court erred when it did not make the disproportionality finding. The trial court addressed the issue of merger at sentencing and there was no error. The trial court erred where it imposed costs in its sentencing entry but did not impose those costs at the sentencing hearing. | Jones | 7/3/2014 | 2014-Ohio-2981
State v. Bauer | 100438 | R.C. 4511.19(G); waiver of counsel. Prior conviction for DUI was properly included within furthermore clause as penalty enhancer during “lookback period” of R.C. 4511.19(G), as record indicated that the court in the prior matter made a finding that defendant knowingly and voluntarily waived his right to counsel. | Kilbane | 7/3/2014 | 2014-Ohio-2980
State v. Moore | 100401 | Mandatory fines, court costs, pat down, handcuffs, traffic stop, detain, arrest, indigence, statutory criteria. The trial court did not error when it denied defendant’s motion to suppress evidence. Defendant’s affidavit of indigence was not properly submitted, and therefore, the trial court was not obligated to consider defendant’s indigency status. The trial court committed reversible error when they failed to impose a mandatory fine and court costs at the sentencing hearing. The trial court’s imposition of a mandatory fine and court costs is reversed with the limited remand for the purpose of a new sentencing hearing. The trial court considered all of the necessary sentencing criteria for this felony conviction. | Gallagher | 7/3/2014 | 2014-Ohio-2979
State v. Tyree | 100377, 100378 | Guilty plea, substantial compliance, failure to advise defendant of potential fine. Judgment affirmed. The trial court’s omission of the possible fines and court costs will not render a plea invalid if the trial court never actually imposed the fines or court costs. In such instances, the defendant cannot show that he would not have entered the plea. | Kilbane | 7/3/2014 | 2014-Ohio-2978
Natl. City Bank v. Goodyear Tire & Rubber Co. | 100178 | R.C. 2125.02/wrongful death/authorized estate representative/statute of limitations; Civ.R. 6(B)/excusable neglect; capacity to sue; Loc.R. 16/case management order; complaint a nullity; loss of consortium. Appellants’ failure to properly identify the proper plaintiff bringing suit did not amount to excusable neglect. Plaintiffs failed to substitute the correct party when they refiled their complaint. The listed party lacked standing to bring the suit. Appellants presented their claim that Loc.R. 16 is unconstitutional for the first time at oral argument. Appellants’ claim on the constitutionality of Loc.R. 16 is waived. Plaintiffs failed, for over a four-year period, to move to amend their complaint or file a substitution of parties, and plaintiffs’ claims were time-barred. Plaintiff’s complaint is a nullity and the trial court did not err in dismissing plaintiffs’ complaint with prejudice. Where a primary cause of action fails, a derivative claim cannot be maintained. | Jones | 7/3/2014 | 2014-Ohio-2977
State v. Black | 100114 | Guilty plea; voluntary; promise of sentence; ineffective assistance of counsel; consistency; R.C. 2929.11(B). Guilty plea entered by defendant who pleaded guilty and gave the police a statement against codefendants, but who received longer sentence than his codefendants, was voluntary because there were no promises made on the record as to what kind of sentence he would receive. The sentence imposed on defendant did not violate R.C. 2929.11(B) because it was only marginally longer than that given to a similar codefendant and the state represented that defendant was the “point man” in the robbery. | Stewart | 7/3/2014 | 2014-Ohio-2976
State v. Hostacky | 100003 | Plain error; witness testimony; prosecutorial misconduct; ineffective assistance of counsel; R.C. 2929.14(D)(1)(b)/consecutive sentences. The officer’s testimony about the victim’s demeanor was not an attempt to vouch for the victim’s credibility, but rather a means to explain why the officer believed the victim had been robbed. The trial court committed no error in allowing the testimony. There was sufficient evidence beyond the prosecutor’s statements made at closing for a finding of guilty. Moreover, the jury was instructed that closing statements are not evidence. There was no prosecutorial misconduct. Defense counsel objected throughout the trial on issues that he saw fit to do so. Defense counsel’s failure to object on other issues did not rise to the level of ineffective assistance. The trial court erred in not merging the two having weapons while under disability counts. | Jones | 7/3/2014 | 2014-Ohio-2975
Cuyahoga Cty. Treasurer v. Samara | 99977 | Delinquent tax certificate for 2009 was prima facie evidence of the amount and validity of the taxes and of their nonpayment. Appellant’s self-created “presentment for value” and her self-created “debt forgiveness voucher” are not currency or legal tender, and are not negotiable instruments, so there has been no valid payment of the tax debt under R.C. 323.14, and foreclosure was properly granted. See R.C. 5721.18. | Kilbane | 7/3/2014 | 2014-Ohio-2974
State v. Robinson | 99917 | Evid.R. 402; relevant evidence; jury instruction; invited error; accomplice instruction; ineffective assistance of counsel; allied offense; aggravated robbery; murder. Court’s instruction that jury could stop deliberating on an “unhung” count was invited error. Court’s responses to jury instructions were proper where the court rephrased its earlier instructions on the elements of each crime. Jury is not required to reach unanimous agreement on alternative theories of principal offender or aider and abettor so long as they unanimously agree beyond a reasonable doubt that the defendant’s actions constituted the offense charged. Counsel was not ineffective for failing to request a unanimity instruction on accomplice liability because it was not required. Aggravated robbery and murder were not allied offenses. | Gallagher | 7/3/2014 | 2014-Ohio-2973
Holloway v. State | 100586 | Judgment affirmed; wrongful imprisonment, R.C. 2743.48, plain meaning. The judgment of the trial court is affirmed; the trial court properly dismissed Holloway’s complaint for wrongful imprisonment as Holloway could not meet all five of the required prongs of the statute; the trial court did not err in relying on evidence outside of the complaint as the evidence relied upon was attached to the complaint by Holloway himself. | Gallagher | 7/3/2014 | 2014-Ohio-2971
Abraitis v. Gallagher | 101037 | Writ of prohibition; subject matter jurisdiction; will contest; declaratory judgment; interested party; standing. Probate court has statutory jurisdiction over will contest and declaratory judgment actions and does not patently and unambiguously lack jurisdiction to determine the standing of a party to those actions. Relator has an adequate remedy at law to challenge the probate court’s determination regarding standing of a party to maintain those actions, therefore, relator has not established the requirements for a writ of prohibition. | Kilbane | 7/2/2014 | 2014-Ohio-2987
State ex rel. Litwinowicz v. Euclid | 101008 | writ of mandamus, defective complaint, adequate remedy at law. Complaint for writ of mandamus is dismissed for procedural defects and for failure to state a claim. | Rocco | 7/1/2014 | 2014-Ohio-2986
State v. Johnson | 46837 | App.R. 26(B) application for reopening, untimely filed, failure to establish good cause for untimely filing. The App.R. 26(B) application for reopening was filed more than ninety days after the journalization of the appellate judgment that is subject to reopening. The applicant failed to establish good cause for the untimely filing of the application for reopening. Thus, this court is prohibited from reopening the applicant’s appeal. | Gallagher | 6/30/2014 | 2014-Ohio-2972
In re D.J. | 101180 | Temporary custody; permanent custody; final appealable order; R.C. 2151.415(D)(4). The denial of a motion to modify temporary custody to permanent custody is still not a final appealable order even in light of an order by the trial court alleged to be in violation of R.C. 2151.415(D)(4). | Gallagher | 6/26/2014 | 2014-Ohio-2778
Siller v. State | 100839 | Summary judgment; lesser-included offense; R.C. 2743.48/wrongful imprisonment retroactive application of court decision. The trial court committed no error in granting appellee’s motion for summary judgment. Appellants pleaded guilty to a lesser-included offense of the originally indicted charge of aggravated robbery and neither appellant made an attempt to set aside those guilty pleas. Appellants were foreclosed from asserting a claim for being wrongfully incarcerated. | Jones | 6/26/2014 | 2014-Ohio-2777
In re A.G. | 100783, 100912 | Child custody; R.C. 2151.23(F)(1); Uniform Child Custody Jurisdiction and Enforcement Act; home state; R.C. 3127.15(A); person acting as a parent. The trial court erred in determining that it lacked jurisdiction over the child custody proceeding. The child lived in Ohio with a “person acting as a parent” for more than six consecutive months prior to the filing of a motion for emergency temporary custody. | Celebrezze | 6/26/2014 | 2014-Ohio-2776
Will Repair, Inc. v. Grange Ins. Co. | 100717 | Summary judgment; declaratory judgment; breach of contract; insurance coverage; contract interpretation; missing property; physical evidence; illusory Trial court did not err in granting summary judgment in favor of insurer on insured’s claims for declaratory judgment and breach of contract for losses allegedly sustained due to theft of insured’s business property. Insurance policy excluded coverage for property stolen by insured’s employees and for missing property for which there was no physical evidence to show what happened to the property. | Rocco | 6/26/2014 | 2014-Ohio-2775
Rogers v. Fuerst | 100670 | Civ.R. 12(B)(6); R.C. 2303.08; R.C. 2303.10. A clerk of court’s failure to file stamp a pleading does not create a jurisdictional defect; filing may be proven by other means. | Boyle | 6/26/2014 | 2014-Ohio-2774
State v. Thornton | 100592 | Sufficiency; manifest weight; trafficking; permitting drug abuse; complicity; aider and abettor; juvenile specification; voir dire. Trafficking and permitting drug abuse convictions affirmed where officers testified they observed drug transaction between defendant, CRI, and a juvenile. Defendant was not prejudiced by juror’s statements during voir dire even though he stated he would be biased in favor of two witnesses. The juror explained that he trained the witnesses as CMHA police officers and worked alongside them. He did not offer an opinion on their honesty or credibility. | Gallagher | 6/26/2014 | 2014-Ohio-2773
Wingfiled v. Cleveland | 100589 | Summary judgment; city; police department; horse; exception to immunity. Trial court properly granted summary judgment to city, police department, and police officers where plaintiff alleged that he had been trampled by the officers’ horses. Police department is not a legal entity capable of being sued, and the city and officers were immune from liability where no exceptions to immunity applied. | Keough | 6/26/2014 | 2014-Ohio-2772
Simmons v. Narine | 100545 | Civ.R. 41(B)(1); Civ.R. 41(B)(3); dismissal of complaint with prejudice; notice; failure to attend court-ordered conference. Trial court did not abuse its discretion in dismissing plaintiff’s complaint with prejudice pursuant to Civ.R. 41(B)(1) after plaintiff twice failed to appear for settlement conference as ordered by the court and court gave notice in judgment entries scheduling settlement conferences that failure to appear could result in dismissal of a party’s claims. | Rocco | 6/26/2014 | 2014-Ohio-2771
In re S.H. | 100529 | Rape; sufficiency of the evidence; manifest weight of the evidence. Based on the victim’s testimony and sexual assault nurse examiner’s testimony, the state presented sufficient evidence to support a delinquency finding of rape. Defendant’s conviction is not against the manifest weight of the evidence; trial court was free to believe the victim over the defendant’s testimony. | Boyle | 6/26/2014 | 2014-Ohio-2770
State v. Davis | 100526 | Criminal nonsupport; R.C. 2919.21(B); R.C. 2919.21(D); affirmative defense; sufficiency of the evidence; manifest weight of the evidence. The state presented sufficient evidence that defendant recklessly disregarded his child support obligation; defendant only made nine separate, partial payments in a 24-month span. Conviction is not against the manifest weight of the evidence; defendant failed to prove by a preponderance of the evidence the affirmative defense contained in R.C. 2919.21(D). Defendant failed to provide support despite satisfying his own needs and desires, including a drug habit. | Boyle | 6/26/2014 | 2014-Ohio-2769
State v. Mango | 100490 | Domestic Violence, Felonious Assault, New Trial, Newly Discovered Evidence. The trial court did not abuse its discretion in denying without a hearing appellant’s motion for a new trial based upon newly discovered evidence after she was convicted of felonious assault and domestic violence. In the affidavit attached to appellant’s motion, the affiant neither indicated the reason appellant could not produce her as a witness at trial, nor offered to testify at a new trial, nor could provide any information relevant to the incident; the affiant’s statements were offered only to impeach the victim’s credibility. | Rocco | 6/26/2014 | 2014-Ohio-2768
In re I.A.G. | 100486 | Appellate practice, failure to fully brief an assignment of error, presumption of regularity in bench trial, scope of remand; Child Support; Evidence, business records. This court presumes that the juvenile court considered only relevant and admissible evidence in determining appellant’s child support obligation. Because appellant admitted that he supplied the copies of his cancelled checks and bank statements for his business upon which the court relied in making its calculations, the business record exception to the hearsay rule applied and the evidence was sufficiently authenticated. The juvenile court’s mandate on remand was to reassess appellant’s child support obligation; therefore, the court did not abuse its discretion in remaining within that scope and permitting the mother simply to testify that her unemployment compensation had remained stable from the time of the previous trial. This court will not address an issue that appellant fails to fully argue in his appellate brief. | Rocco | 6/26/2014 | 2014-Ohio-2767
State v. Bonds | 100481 | Maximum sentence; felony sentencing; R.C. 2929.11 and 2929.12; contrary to law. The trial court satisfied the requirements outlined in R.C. 2929.11 and 2929.12 when it imposed a maximum sentence. The sentence is therefore not contrary to law. | McCormack | 6/26/2014 | 2014-Ohio-2766
Bank of New York Mellon v. Hutchins | 100435 | Mortgage; note; standing, res judicata; Civ.R. 60(B); appeal; jurisdiction. Res judicata bars appellant’s claims where issue of standing was litigated and adjudicated by the trial court prior to granting summary judgment in favor of bank. A Civ.R. 60(B) motion cannot be used as a substitute for an appeal. | Stewart | 6/26/2014 | 2014-Ohio-2765
State v. Rosa | 100324, 100325 | Ineffective assistance of counsel; sufficiency of the evidence; trespass element; parking lot. Defendant’s ineffective assistance of counsel claim lacks merit; defendant failed to demonstrate a reasonable probability that the proceedings would have been different had his trial counsel requested a more specific bill of particulars or moved to dismiss the indictment. State presented sufficient evidence as to the element of trespass to support the breaking and entering count; defendant was neither a tenant nor visitor at the time that he entered the private parking lot, and defendant was subject to an order of protection that expressly prohibited him from entering the victim’s parking lot. | Boyle | 6/26/2014 | 2014-Ohio-2764
State v. Jones | 100300 | motion to suppress; drugs; informant; loud music; search and seizure; odor of marijuana; dog; reasonable suspicion; pat-down search; exigent circumstances; plain feel; metropolitan housing authority; deputy sheriffs; R.C. 2935.03(D); exclusionary rule. Denial of motion to suppress was proper where metropolitan housing authority officers conducted a lawful traffic stop, had reasonable suspicion to investigate further, and conducted a lawful search and seizure. The police initiated a traffic stop for a violation of a city ordinance prohibiting loud music from a motor vehicle, and during the investigatory stop the officers developed a reasonable suspicion that appellant was engaged in criminal activity. The officers also had probable cause to search appellant’s person for drugs. The odor of marijuana was detected from the vehicle appellant was driving; a drug dog alerted to the odor of drugs from the vehicle; appellant was seen making a furtive movement in the vehicle; the vehicle matched the description provided by an informant and was traveling into the area of an arranged drug-buy. The metropolitan housing authority officers were sworn deputy sheriffs with authority to arrest anywhere in the county, and an arrest made in violation of R.C. 2935.03(D) is not a constitutional violation subject to the exclusionary rule. | Gallagher | 6/26/2014 | 2014-Ohio-2763
State v. Pitra | 100284 | Burglary, ineffective assistance of counsel. Trial counsel did not provide ineffective assistance in failing to call a potential witness. Trial court did not abuse its discretion in allowing the homeowner to testify about her fear during a burglary incident. | McCormack | 6/26/2014 | 2014-Ohio-2761
Reese v. George | 100276 | Insured; plain meaning; declaratory judgment; summary judgment; conduct of business. Trial court properly granted summary judgment to insurer in declaratory judgment action because defendant was not an insured under the commercial liability policy; defendant’s actions were personal in nature and not related to the conduct of his businesses. | Keough | 6/26/2014 | 2014-Ohio-2760
State v. Stephens | 99051 | Consecutive sentences; conceded error. Trial court did not make the necessary findings to support the imposition of consecutive sentences. The state concedes the error. | McCormack | 6/26/2014 | 2014-Ohio-2759
State ex rel. Velez v. Russo | 101332 | Mandamus, motion for jail time credit, Loc.App.R. 45(B)(1)(a) sworn affidavit, R.C. 2969.25(A) affidavit of past civil actions and appeals, R.C. 2969.25(C) statement of balance in inmate account and other cash/valuables. Relator’s complaint for a writ of mandamus is moot. Respondent granted relator’s motion for jail time credit. In addition, relator’s complaint is subject to dismissal for failure to comply with Loc.App.R. 45(B)(1)(a), R.C. 2969.25(A), and 2969.25(C). | McCormack | 6/23/2014 | 2014-Ohio-2779
State v. Grant | 100497 | Consecutive sentences; costs. Trial court did not err in imposing consecutive sentences for three counts of rape and one count of aggravated robbery. The trial court committed plain error in imposing court costs in its sentencing entry without informing him of those costs in open court. | Kilbane | 6/19/2014 | 2014-Ohio-2656
State v. Kimmie | 100750 | Motion to withdraw; motion to dismiss appeal; Anders brief; R.C. 2929.14(C)(4)/consecutive sentences. At appellant’s resentencing, the trial court complied with making the necessary findings under R.C. 2929.14(C), and that being the only possible issue for review on appeal, appellant’s appeal is frivolous and dismissed. | Jones | 6/19/2014 | 2014-Ohio-2653
In re J.G. | 100681 | Permanent custody; best interest of the child; R.C. 2151.414; clear and convincing; abandoned; notice requirements; Juv.R. 29; adjudicatory and dispositional hearing; Juv.R. 34; R.C. 2151.35; ineffective assistance of counsel. Clear and convincing evidence supports the trial court’s determination that the mother abandoned the child and permanent custody to the agency is in the best interest of the child. Notice requirements of Juv.R. 29(B) were satisfied. The trial court did not err in proceeding immediately to dispositional hearing following the adjudicatory hearing as the requirements of R.C. 2151.35 and Juv.R. 34 had been satisfied. Counsel was not ineffective for consenting to immediate disposition as the mother has failed to demonstrate how delaying the proceedings would have changed the outcome of the proceedings. | McCormack | 6/19/2014 | 2014-Ohio-2652
Beckman v. Playhouse Square Found. | 100627 | Premises liability; open-and-obvious doctrine; assumption of the risk; negligence; attendant circumstances. The trial court properly granted summary judgment to a premises owner where a volunteer employee fell during evacuation training because the volunteer was aware of the risks of participation and assumed them. | Celebrezze | 6/19/2014 | 2014-Ohio-2651
Levy v. Levy | 100609 | R.C. 3105.18(C)(1)/modification of spousal support; jurisdiction; contempt; R.C. 3105.73/attorney fees; abuse of discretion; arrearage. The separation agreement and divorce decree expressly reserved the trial court its right to retain jurisdiction to modify spousal support, and the change in circumstance was not one contemplated. The trial court did have jurisdiction. Although a reduction in spousal support was warranted, the trial court abused its discretion in lowering the support to the amount that it did. The trial court, given its broad discretion in fashioning equitable relief, did not abuse its discretion in not finding appellee in contempt. The trial court did not abuse its discretion where neither party was found to not be without fault. | Jones | 6/19/2014 | 2014-Ohio-2650
Huntington Natl. Bank v. Brown | 100567 | Summary judgment; foreclosure; MERS; standing; mortgage; note assignment; endorsement. MERS has authority to assign a mortgage when it is designated as both a nominee and mortgagee; a party may establish its interest in the suit, and therefore have standing to invoke the jurisdiction of the court when, at the time it files its complaint of foreclosure, it either (1) has had a mortgage assigned or (2) is the holder of the note; Huntington was the real party in interest, and therefore had standing to bring this foreclosure action; the trial court did not err in granting summary judgment in favor of Huntington. | Celebrezze | 6/19/2014 | 2014-Ohio-2649
State v. Jackson | 100519 | Postrelease control; resentencing. Once the underlying sentence has been completed, the trial court could no longer resentence a defendant to correct its flawed imposition of postrelease control. | McCormack | 6/19/2014 | 2014-Ohio-2648
State v. Lime | 100515 | R.C. 2929.14(C); Consecutive Sentences. The trial court failed to comply with R.C. 2929.14(C) by failing to make the requisite findings. | Blackmon | 6/19/2014 | 2014-Ohio-2647
State v. Johnson | 100503 | R.C. 2953.74(B)(1) and (2); application for postconviction DNA testing. The trial court abused its discretion by denying the appellant’s application for postconviction DNA testing because at the time of trial DNA testing was not as sophisticated as it is presently. Also, the results of the DNA testing would be “outcome determinative because only one perpetrator committed the robbery and another person had confessed to committing the robbery. | Blackmon | 6/19/2014 | 2014-Ohio-2646
State v. Frost | 100498 | Consecutive sentence; statutory findings; the trial court’s duty upon remand. When a criminal sentence is remanded for resentencing due to a trial court’s failure to make all three statutory findings for consecutive sentences, the scope of the remand is limited to the finding(s) lacking at the original sentencing hearing. | McCormack | 6/19/2014 | 2014-Ohio-2645
State v. Webb | 100487 | theft in office; R.C. 2921.41(A)(1); ineffective assistance; photo array; unduly suggestive; refresh recollection; Evid.R. 612; impeach; sufficiency; manifest weight. Appellant’s conviction for theft in office in violation of R.C. 2921.41(A)(1) was affirmed where six witnesses testified to giving money to a male bailiff, three of whom were shown and identified appellant from a photo array, appellant was the only male bailiff permanently assigned to the courtroom in which they appeared, and a codefendant testified she and appellant cooperated in stealing money from the Cleveland Municipal Court. Defense counsel was not ineffective for withdrawing a motion to suppress identification evidence when the photo arrays were not unduly suggestive. The state properly used a prior statement to refresh the recollection of a witness pursuant to Evid.R. 612, rather than to impeach the witness with a prior inconsistent statement. Sufficient evidence was presented to show the total amount stolen was greater than $500, and appellant’s conviction was not against the manifest weight of the evidence. | Gallagher | 6/19/2014 | 2014-Ohio-2644
State v. Earley | 100482 | allied offenses, aggravated vehicular assault, OVI, R.C. 2929.41(B)(3), double jeopardy. Assuming arguendo that aggravated vehicular assault and OVI are allied offenses, the General Assembly through R.C. 2929.41(B)(3) created an exception that allows a trial court to impose a sentence for both offenses. | Keough | 6/19/2014 | 2014-Ohio-2643

Page: [ 1] 2 3 4 5 6 next